@@ -255,7 +255,7 @@ def set_idemailstatus_target_column(df):
         df.insert(loc=2, value=bv_col, column='BV')
         idcampaign_col = df['idCampaign']
         df.drop(labels=['idCampaign'], axis=1, inplace=True)
-        df.insert(loc=3, value=idcampaign_col, column='BV')
+        df.insert(loc=3, value=idcampaign_col, column='idCampaign')
 
     else:
         logger.error('No IDEmailSTatus column found')
